package object_detection;

import object_detection.types.ObjectSet;
import object_detection.types.Point;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.nio.file.Files;
import java.util.Arrays;
import java.util.Scanner;

public class ObjectDetector {

    public static ObjectSet process(String bbox_dir_pth, String feat_dir_pth){

        File[] feat_CSVs = getDirFiles(feat_dir_pth);
        File[] bbox_CSVs = getDirFiles(bbox_dir_pth);

        // check to make sure both file arrays have same number of keyframes (for consistency)
        if(feat_CSVs.length != bbox_CSVs.length){
            System.err.println("ERROR: features and bounding box directories have differing number of Keyframes");
        }

        // initialize ObjectSet
        ObjectSet objSet = new ObjectSet();

        // for each keyframe, process bounding box csv and feature csv
        int NUMKF = feat_CSVs.length;

        for(int i = 0; i < NUMKF; i++){
            objSet.processFrame(feat_CSVs[i], bbox_CSVs[i]);
        }

        // return the completely built object set
        return objSet;
    }

    public static File[] getDirFiles(String dir_pth){
        File[] f_arr;
        // get the csv files of each frame
        try {
            f_arr = new File(dir_pth).listFiles();
        } catch (Exception e) {
            throw new RuntimeException(e);
        }

        // some error checking
        if(f_arr == null || f_arr.length == 0){
            System.err.println("ERROR: no feature csvs found at given path");
        }

        return f_arr;
    }

}
