package object_detection.types;

import java.io.File;
import java.util.*;

public class ObjectSet {

    public static List<PointSet> objects;
    static int count = 0;
    public ObjectSet(){
        objects = new ArrayList<>();
    }

    /**
     * This method is used to create a new object (or candidate), that will then be compared to others
     * @param pp : the points that will be used as features
     * @return : the index of this object, so we can quickly add and remove objects from list
     */
    public int makeObject(Point...pp){
        PointSet ps = new PointSet();
        ps.addAll(pp);
        count++;
        ps.updateReps();

        // add pointset to object list
        objects.add(count-1, ps);

        // return index of new object
        return count-1;
    }

    /**
     * We compare two objects
     * @param i : should be the already in database object
     * @param j : the new candidate object
     * @return true if objects are the same
     */
    public static boolean compareObjects(int i, int j){
        Point[] r1 = objects.get(i).getSetReps();
        Point[] r2 = objects.get(j).getSetReps();

        // compare r1 and r2
        Set<Point> s = new HashSet<>();
        for(Point r : r1){
            if(r != null){
                s.add(r);
            }
        }

        int count = 0;
        for(Point p : r2){
            if(p!=null && s.contains(p)){
                count++;
            }
        }

        // in this line, if the reps are 80% similar, assume this is the same set.
        return (count) > (r1.length*0.8);
    }

    /**
     * This function merges object j into object i (these are indexes in objects set)
     * @param i : current object in list
     * @param j : new object to be combined into i
     */
    public void combineObjects(int i, int j){

        // add all points of j to i
        objects.get(i).addAll(objects.get(j).getPoints());

        // redo reps of the object with new points
        objects.get(i).updateReps();

        // remove j
        objects.remove(j);

        // eventually, push i to database
    }

    /**
     * This method updates the ObjectSet to incorporate new information from the features and bounding boxes of a new keyframe.
     *
     * @param featCsv : file containing each feature in space (x,y,z and index)
     * @param bboxCsv : file containing Bounding Boxes for each object in a keyframe
     */
    public void processFrame(File featCsv, File bboxCsv) {
        return;
    }
}